FlutterLocalization class

Properties

currentLocale → Locale?
Get the current locale of the app.
no setter
fontFamily → String?
Provide the font family by the current locale's language code
no setter
hashCode → int
The hash code for this object.
no setterinherited
localizationsDelegates → Iterable<LocalizationsDelegate>
Apply all the needed delegate and the package delegate for the app. This will use at the MaterialApp
no setter
onTranslatedLanguage ↔ TranslatorCallback?
Callback for the translation. This will call after the translate function is called.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedLanguageCodes → List<String>
Get the list of supported language code provided by the init function
no setter
supportedLocales → Iterable<Locale>
Generate the supported locales for the app. This will use at the MaterialAap
no setter

Methods

ensureInitialized() → Future<void>
To ensure the currentLocale object is provided before runApp
getLanguageName({String? languageCode}) → String
This just call the getName() function from FlutterLocalizationTranslator class for getting the full language name by the language code.
init({required String initLanguageCode, LocalizationSource source = LocalizationSource.map, List<MapLocale>? mapLocales, List<JsonLocale>? jsonLocales}) → void
Initialize the localization configuration.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
translate(String languageCode, {bool save = true}) → void
Call this function at where you want to translate the app like by pressing the button or any actions.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → FlutterLocalization
The instance object of FlutterLocalization class.
final